@@ -31,7 +31,7 @@
 /*
  * The version number reported by the program. This should not be bothered...
  */
-#define CFG_VIDEOGEN_VERSION "0.30"
+#define CFG_VIDEOGEN_VERSION "0.31"
 
 
 
@@ -86,19 +86,19 @@
  * horizontal front porch interval (must be n*8)
  * default: 32 [ticks]
  */
-#define CFG_HORIZ_FRONT_PORCH 32
+#define CFG_HORIZ_FRONT_PORCH 64
 
 /*
  * horizontal back porch interval (must be n*8)
- * default: 32 [ticks]
+ * default: 64 [ticks]
  */
-#define CFG_HORIZ_BACK_PORCH 32
+#define CFG_HORIZ_BACK_PORCH 128
 
 /*
- * default horizontal sync pulse duration
- * default: 1 [us]
+ * default minimum horizontal sync pulse duration
+ * default: 0.5 [us]
  */
-#define CFG_HORIZ_SYNC_PULSE 1
+#define CFG_HORIZ_SYNC_PULSE 0.5
 
 /*
  * vertical front porch interval
@@ -108,15 +108,15 @@
 
 /*
  * vertical back porch interval
- * default: 2 [ticks]
+ * default: 32 [ticks]
  */
-#define CFG_VERT_BACK_PORCH 2
+#define CFG_VERT_BACK_PORCH 32
 
 /*
  * default vertical sync pulse duration
- * default: 150 [us]
+ * default: 50 [us]
  */
-#define CFG_VERT_SYNC_PULSE 150
+#define CFG_VERT_SYNC_PULSE 50
 
 /*
  * default limits for hardware parameter bounds checking
@@ -140,18 +140,18 @@
 #define CFG_HORIZ_VISIBLE_MAX		97
 #define CFG_VERT_VISIBLE_MIN		70
 #define CFG_VERT_VISIBLE_MAX		99
-#define CFG_HORIZ_FRONT_PORCH_MIN	30
-#define CFG_HORIZ_FRONT_PORCH_MAX	80
-#define CFG_HORIZ_BACK_PORCH_MIN	30
-#define CFG_HORIZ_BACK_PORCH_MAX	80
-#define CFG_HORIZ_SYNC_PULSE_MIN	0.5
-#define CFG_HORIZ_SYNC_PULSE_MAX	3
+#define CFG_HORIZ_FRONT_PORCH_MIN	32
+#define CFG_HORIZ_FRONT_PORCH_MAX	512
+#define CFG_HORIZ_BACK_PORCH_MIN	32
+#define CFG_HORIZ_BACK_PORCH_MAX	512
+#define CFG_HORIZ_SYNC_PULSE_MIN	0.3
+#define CFG_HORIZ_SYNC_PULSE_MAX	1.5
 #define CFG_VERT_FRONT_PORCH_MIN	0
-#define CFG_VERT_FRONT_PORCH_MAX	10
+#define CFG_VERT_FRONT_PORCH_MAX	256
 #define CFG_VERT_BACK_PORCH_MIN		0
-#define CFG_VERT_BACK_PORCH_MAX		10
-#define CFG_VERT_SYNC_PULSE_MIN		50
-#define CFG_VERT_SYNC_PULSE_MAX		250
+#define CFG_VERT_BACK_PORCH_MAX		256
+#define CFG_VERT_SYNC_PULSE_MIN		30
+#define CFG_VERT_SYNC_PULSE_MAX		150
 #define CFG_NV_MAX_HBLANK		1016
 #define CFG_NV_MAX_HSP			256
 #define CFG_NV_MAX_VBLANK		128
