@@ -73,10 +73,6 @@ banner (void)
 	pmsg (VL_VERBOSE, "       |        THIS PROGRAM COMES WITH ABSOLUTELY NO WARRANTY        |\n");
 	pmsg (VL_VERBOSE, "       |    for details see the GNU General Public License (GPLv2)    |\n");
 	pmsg (VL_VERBOSE, "       |                                                              |\n");
-	pmsg (VL_VERBOSE, "       |                  calculations are based on                   |\n");
-	pmsg (VL_VERBOSE, "       |     The Hitchhiker's Guide to X386/XFree86 Video Timing      |\n");
-	pmsg (VL_VERBOSE, "       |          by Chin Fang, Bob Crosson, Eric S. Raymond          |\n");
-	pmsg (VL_VERBOSE, "       |                                                              |\n");
 	pmsg (VL_VERBOSE, "       +--------------------------------------------------------------+\n\n");
 }
 
@@ -103,8 +99,7 @@ main (int argc, char **argv)
 	arg_parse_t ap = { 0, 0, 0, NULL, &opts };
 	int i;
 	double calc_dc, calc_hf, calc_vf;
-	unsigned int calc_hfl, calc_vfl, calc_hsp, calc_vsp;
-	double nv_hsync_corr1, nv_hsync_corr2, nv_vsync_corr1, nv_vsync_corr2;
+	unsigned int calc_hfl, calc_vfl, calc_hfp, calc_hsp, calc_hbp, calc_vfp, calc_vsp, calc_vbp;
 
 
 
@@ -206,8 +201,7 @@ main (int argc, char **argv)
 	for (i = 0; i < num_modes; i++)
 	{
 		calc_vf = desired_vfreq;
-		calc_hfl = (unsigned int)floor (modes[i].hres * 100 / hvisible + 0.5);
-		calc_hfl = (unsigned int)floor (calc_hfl / 8) * 8;
+		calc_hfl = (unsigned int)floor (modes[i].hres * 100 / hvisible / 8) * 8;
 
 		if ((nvidia > 0) && (calc_hfl - modes[i].hres > CFG_NV_MAX_HBLANK))
 		{
@@ -217,23 +211,22 @@ main (int argc, char **argv)
 			calc_hfl = (unsigned int)floor (calc_hfl / 8) * 8;
 		}
 
-		calc_hsp = (unsigned int) calc_hfl - modes[i].hres - hfporch - hbporch;
+		calc_hfp = (unsigned int)floor ((calc_hfl - modes[i].hres) / 64) * 8;
+		calc_hbp = (unsigned int)floor ((calc_hfl - modes[i].hres - calc_hfp) / 8) * 8; 
+
+		calc_hsp = floor (hsync * max_dotclk / 8) * 8;
 
 		if ((nvidia > 0) && (calc_hsp > CFG_NV_MAX_HSP))
 		{
 			/* calc_hsp is assumed to be a multiple of 8 because all values it is
-			 * calculated from are assumed to be multiples of 8. this means that
-			 * nv_hsync_corr[12] can be assumed to be a multiple of 4.
-			 * the framelenght must be the same after the correction.
+			 * calculated from are assumed to be multiples of 8.
 			 */
 			pmsg (VL_DEBUG, "[main] hsp: %u > %u\n", calc_hsp, CFG_NV_MAX_HSP);
-			nv_hsync_corr1 = floor ((calc_hsp - CFG_NV_MAX_HSP) / 2);
-			nv_hsync_corr2 = calc_hsp - CFG_NV_MAX_HSP - nv_hsync_corr1;
-			hfporch += nv_hsync_corr1;
-			hbporch += nv_hsync_corr2;
-			calc_hsp -= nv_hsync_corr1 + nv_hsync_corr2;
+			calc_hsp = CFG_NV_MAX_HSP;
 		}
 
+		calc_hbp -= calc_hsp;
+
 		calc_vfl = (unsigned int)floor (modes[i].vres * 100 / vvisible + 0.5);
 
 		if ((nvidia > 0) && (calc_vfl - modes[i].vres > CFG_NV_MAX_VBLANK))
@@ -243,22 +236,23 @@ main (int argc, char **argv)
 			calc_vfl = (unsigned int)floor (modes[i].vres * 100 / vvisible);
 		}
 
-		calc_vsp = (unsigned int)calc_vfl - modes[i].vres - vfporch - vbporch;
+		calc_dc = calc_vf * calc_hfl * calc_vfl / 1000000;
+		calc_hf = (1000 * calc_dc) / calc_hfl;
+
+		calc_vfp = (unsigned int)vfporch;
+		calc_vbp = calc_vfl - modes[i].vres - calc_vfp;
+
+		calc_vsp = floor (vsync * calc_hf / 1000);
 
 		if ((nvidia > 0) && (calc_vsp > CFG_NV_MAX_VSP))
 		{
 			/* framelength must be the same after the correction
 			 */
 			pmsg (VL_DEBUG, "[main] vsp: %u > %u\n", calc_vsp, CFG_NV_MAX_VSP);
-			nv_vsync_corr1 = floor ((calc_vsp - CFG_NV_MAX_VSP) / 2);
-			nv_vsync_corr2 = calc_vsp - CFG_NV_MAX_VSP - nv_vsync_corr1;
-			vfporch += nv_vsync_corr1;
-			vbporch += nv_vsync_corr2;
-			calc_vsp -= nv_vsync_corr1 + nv_vsync_corr2;
+			calc_vsp = CFG_NV_MAX_VSP;
 		}
 
-		calc_dc = calc_vf * calc_hfl * calc_vfl / 1000000;
-		calc_hf = (1000 * calc_dc) / calc_hfl;
+		calc_vbp -= calc_vsp;
 
 		pmsg (VL_DEBUG, "[main] dump 1: visible=%ux%u frame=%ux%u\n", modes[i].hres, modes[i].vres, calc_hfl, calc_vfl);
 		pmsg (VL_DEBUG, "[main] dump 1: dc=%f hf=%f vf=%f\n", calc_dc, calc_hf, calc_vf);
@@ -289,30 +283,6 @@ main (int argc, char **argv)
 		pmsg (VL_DEBUG, "[main] dump 3: dc=%f hf=%f vf=%f\n", calc_dc, calc_hf, calc_vf);
 		pmsg (VL_DEBUG, "[main] dump 3: hsp=%u vsp=%u\n\n", calc_hsp, calc_vsp);
 
-		if ((calc_hsp / calc_dc) < hsync)
-		{
-			pmsg (VL_DEBUG, "[main] hsp: %f < %f\n", calc_hsp / calc_dc, hsync);
-			calc_dc = calc_hsp / hsync;
-			calc_vf = (1000000 * calc_dc) / (calc_hfl * calc_vfl);
-			calc_hf = (1000 * calc_dc) / calc_hfl;
-		}
-
-		pmsg (VL_DEBUG, "[main] dump 4: visible=%ux%u frame=%ux%u\n", modes[i].hres, modes[i].vres, calc_hfl, calc_vfl);
-		pmsg (VL_DEBUG, "[main] dump 4: dc=%f hf=%f vf=%f\n", calc_dc, calc_hf, calc_vf);
-		pmsg (VL_DEBUG, "[main] dump 4: hsp=%u vsp=%u\n\n", calc_hsp, calc_vsp);
-
-		if ((calc_vsp / calc_hf * 1000) < vsync)
-		{
-			pmsg (VL_DEBUG, "[main] vsp: %f < %f\n", calc_vsp / calc_hf * 1000, vsync);
-			calc_hf = calc_vsp / vsync * 1000;
-			calc_dc = calc_hf * calc_hfl / 1000;
-			calc_vf = (1000000 * calc_dc) / (calc_hfl * calc_vfl);
-		}
-
-		pmsg (VL_DEBUG, "[main] dump 5: visible=%ux%u frame=%ux%u\n", modes[i].hres, modes[i].vres, calc_hfl, calc_vfl);
-		pmsg (VL_DEBUG, "[main] dump 5: dc=%f hf=%f vf=%f\n", calc_dc, calc_hf, calc_vf);
-		pmsg (VL_DEBUG, "[main] dump 5: hsp=%u vsp=%u\n\n", calc_hsp, calc_vsp);
-
 		/*
 		 * printing out the results
 		 */
@@ -323,21 +293,19 @@ main (int argc, char **argv)
 				modes[i].hres, modes[i].vres,
 				calc_dc,
 				modes[i].hres,
-				modes[i].hres + (unsigned int)hfporch,
-				modes[i].hres + (unsigned int)hfporch + calc_hsp,
-				modes[i].hres + (unsigned int)hfporch + calc_hsp + (unsigned int)hbporch,
+				modes[i].hres + calc_hfp,
+				modes[i].hres + calc_hfp + calc_hsp,
+				modes[i].hres + calc_hfp + calc_hsp + calc_hbp,
 				modes[i].vres,
-				modes[i].vres + (unsigned int)vfporch,
-				modes[i].vres + (unsigned int)vfporch + calc_vsp,
-				modes[i].vres + (unsigned int)vfporch + calc_vsp + (unsigned int)vbporch,
+				modes[i].vres + calc_vfp,
+				modes[i].vres + calc_vfp + calc_vsp,
+				modes[i].vres + calc_vfp + calc_vsp + calc_vbp,
 				calc_dc, calc_hf, calc_vf);
 		}
 		else
 		{
 			fprintf (stdout, "timings %0.0f %u %u %u %u %u %u  # %0.0f MHz, %0.1f kHz, %0.1f Hz\n",
-				1000000 / calc_dc,
-				(unsigned int)hbporch, (unsigned int)hfporch, (unsigned int)vbporch, (unsigned int)vfporch,
-				calc_hsp, calc_vsp,
+				1000000 / calc_dc, calc_hbp, calc_hfp, calc_vbp, calc_vfp, calc_hsp, calc_vsp,
 				calc_dc, calc_hf, calc_vf);
 		}
 	}
